@@ -36,13 +36,11 @@ enum {
 	,COLUMNS_NULLABLE
 	,COLUMNS_REMARKS
 	,COLUMNS_COLUMN_DEF /* ODBC 3.0 but always use it */
-#if (ODBCVER >= 0x0300)
 	,COLUMNS_SQL_DATA_TYPE
 	,COLUMNS_SQL_DATETIME_SUB
 	,COLUMNS_CHAR_OCTET_LENGTH
 	,COLUMNS_ORDINAL_POSITION
 	,COLUMNS_IS_NULLABLE
-#endif	/* ODBCVER */
 	,COLUMNS_DISPLAY_SIZE
 	,COLUMNS_FIELD_TYPE
 	,COLUMNS_AUTO_INCREMENT
@@ -77,9 +75,7 @@ enum {
 	,FKS_DELETE_RULE
 	,FKS_FK_NAME
 	,FKS_PK_NAME
-#if (ODBCVER >= 0x0300)
 	,FKS_DEFERRABILITY
-#endif	/* ODBCVER */
 	,FKS_TRIGGER_NAME
 	,NUM_OF_FKS_FIELDS
 };
@@ -148,14 +144,12 @@ enum {
         ,PROCOLS_NUM_PREC_RADIX
         ,PROCOLS_NULLABLE
         ,PROCOLS_REMARKS
-#if (ODBCVER >= 0x0300)
         ,PROCOLS_COLUMN_DEF
         ,PROCOLS_SQL_DATA_TYPE
         ,PROCOLS_SQL_DATETIME_SUB
         ,PROCOLS_CHAR_OCTET_LENGTH
         ,PROCOLS_ORDINAL_POSITION
         ,PROCOLS_IS_NULLABLE
-#endif /* ODBCVER */
 	,NUM_OF_PROCOLS_FIELDS
 };
 #endif /* __CARFUNC_H__ */
