@@ -16,11 +16,12 @@
 #include "columninfo.h"
 
 #include "connection.h"
-#include "socket.h"
 #include <stdlib.h>
 #include <string.h>
 #include "pgapifunc.h"
 
+#include <libpq-fe.h>
+
 ColumnInfoClass *
 CI_Constructor(void)
 {
@@ -47,14 +48,13 @@ CI_Destructor(ColumnInfoClass *self)
 	free(self);
 }
 
-
 /*
- *	Read in field descriptions.
+ *	Read in field descriptions from a libpq result set.
  *	If self is not null, then also store the information.
  *	If self is null, then just read, don't store.
  */
-char
-CI_read_fields(ColumnInfoClass *self, ConnectionClass *conn)
+BOOL
+CI_read_fields_from_pgres(ColumnInfoClass *self, PGresult *pgres)
 {
 	CSTR		func = "CI_read_fields";
 	Int2		lf;
@@ -62,24 +62,17 @@ CI_read_fields(ColumnInfoClass *self, ConnectionClass *conn)
 	OID		new_adtid, new_relid = 0, new_attid = 0;
 	Int2		new_adtsize;
 	Int4		new_atttypmod = -1;
-
-	/* COLUMN_NAME_STORAGE_LEN may be sufficient but for safety */
-	char		new_field_name[2 * COLUMN_NAME_STORAGE_LEN + 1];
-	SocketClass *sock;
-	ConnInfo   *ci;
-
-	sock = CC_get_socket(conn);
-	ci = &conn->connInfo;
+	char	   *new_field_name;
 
 	/* at first read in the number of fields that are in the query */
-	new_num_fields = (Int2) SOCK_get_int(sock, sizeof(Int2));
+	new_num_fields = PQnfields(pgres);
 
 	mylog("num_fields = %d\n", new_num_fields);
 
 	if (self)
 	{
 		/* according to that allocate memory */
-		CI_set_num_fields(self, new_num_fields, PROTOCOL_74(ci));
+		CI_set_num_fields(self, new_num_fields);
 		if (NULL == self->coli_array)
 			return FALSE;
 	}
@@ -87,38 +80,28 @@ CI_read_fields(ColumnInfoClass *self, ConnectionClass *conn)
 	/* now read in the descriptions */
 	for (lf = 0; lf < new_num_fields; lf++)
 	{
-		SOCK_get_string(sock, new_field_name, 2 * COLUMN_NAME_STORAGE_LEN);
-		if (PROTOCOL_74(ci))	/* tableid & columnid */
+		new_field_name = PQfname(pgres, lf);
+		new_relid = PQftable(pgres, lf);
+		new_attid = PQftablecol(pgres, lf);
+		new_adtid = PQftype(pgres, lf);
+		new_adtsize = PQfsize(pgres, lf);
+
+		mylog("READING ATTTYPMOD\n");
+		new_atttypmod = PQfmod(pgres, lf);
+
+		/* Subtract the header length */
+		switch (new_adtid)
 		{
-			new_relid = SOCK_get_int(sock, sizeof(Int4));
-			new_attid = SOCK_get_int(sock, sizeof(Int2));
-		}
-		new_adtid = (OID) SOCK_get_int(sock, 4);
-		new_adtsize = (Int2) SOCK_get_int(sock, 2);
-
-		/* If 6.4 protocol, then read the atttypmod field */
-		if (PG_VERSION_GE(conn, 6.4))
-		{
-			mylog("READING ATTTYPMOD\n");
-			new_atttypmod = (Int4) SOCK_get_int(sock, 4);
-
-			/* Subtract the header length */
-			switch (new_adtid)
-			{
-				case PG_TYPE_DATETIME:
-				case PG_TYPE_TIMESTAMP_NO_TMZONE:
-				case PG_TYPE_TIME:
-				case PG_TYPE_TIME_WITH_TMZONE:
-					break;
-				default:
-					new_atttypmod -= 4;
-			}
-			if (new_atttypmod < 0)
-				new_atttypmod = -1;
-			if (PROTOCOL_74(ci))	/* format */
-				SOCK_get_int(sock, sizeof(Int2));
-
+			case PG_TYPE_DATETIME:
+			case PG_TYPE_TIMESTAMP_NO_TMZONE:
+			case PG_TYPE_TIME:
+			case PG_TYPE_TIME_WITH_TMZONE:
+				break;
+			default:
+				new_atttypmod -= 4;
 		}
+		if (new_atttypmod < 0)
+			new_atttypmod = -1;
 
 		mylog("%s: fieldname='%s', adtid=%d, adtsize=%d, atttypmod=%d (rel,att)=(%d,%d)\n", func, new_field_name, new_adtid, new_adtsize, new_atttypmod, new_relid, new_attid);
 
@@ -126,7 +109,7 @@ CI_read_fields(ColumnInfoClass *self, ConnectionClass *conn)
 			CI_set_field_info(self, lf, new_field_name, new_adtid, new_adtsize, new_atttypmod, new_relid, new_attid);
 	}
 
-	return (SOCK_get_errcode(sock) == 0);
+	return TRUE;
 }
 
 
@@ -155,7 +138,7 @@ CI_free_memory(ColumnInfoClass *self)
 
 
 void
-CI_set_num_fields(ColumnInfoClass *self, int new_num_fields, BOOL allocrelatt)
+CI_set_num_fields(ColumnInfoClass *self, int new_num_fields)
 {
 	CI_free_memory(self);		/* always safe to call */
 
