@@ -1086,15 +1086,6 @@ writeDriverCommoninfo(const char *fileName, const char *sectionName,
 	sprintf(tmp, "%d", comval->unique_index);
 	if (!SQLWritePrivateProfileString(sectionName, INI_UNIQUEINDEX, tmp, fileName))
 		errc--;
-	/*
-	 * Never update the onlyread from this module.
-	 */
-	if (stricmp(ODBCINST_INI, fileName) == 0)
-	{
-		sprintf(tmp, "%d", comval->onlyread);
-		SQLWritePrivateProfileString(sectionName, INI_READONLY, tmp,
-									 fileName);
-	}
 
 	sprintf(tmp, "%d", comval->use_declarefetch);
 	if (!SQLWritePrivateProfileString(sectionName, INI_USEDECLAREFETCH, tmp, fileName))
@@ -1544,6 +1535,8 @@ decode(const char *in)
 		return out;
 	}
 	outs = (char *) malloc(ilen + 1);
+	if (!outs)
+		return out;
 	for (i = 0; i < ilen; i++)
 	{
 		inc = in[i];
@@ -1687,6 +1680,8 @@ char *extract_extra_attribute_setting(const pgNAME setting, const char *attr)
 	if (!sptr)
 		return NULL;
 	rptr = malloc(len + 1);
+	if (!rptr)
+		return NULL;
 	memcpy(rptr, sptr, len);
 	rptr[len] = '\0';
 	mylog("extracted a %s '%s' from %s\n", attr, rptr, str);
