@@ -38,15 +38,11 @@ extern "C" {
 
 #define	ODBC_DATASOURCES	"ODBC Data Sources"
 
-#if (ODBCVER >= 0x0300)
 #ifdef  UNICODE_SUPPORT
 #define INI_DSN				"PostgreSQL35W"
 #else
 #define INI_DSN				"PostgreSQL30"
 #endif /* UNICODE_SUPPORT */
-#else
-#define INI_DSN				DBMS_NAME
-#endif   /* ODBCVER */
 
 #define INI_KDESC			"Description"	/* Data source
 							 * description */
@@ -66,21 +62,29 @@ extern "C" {
 #define ABBR_DEBUG			"B2"
 #define INI_FETCH			"Fetch"		/* Fetch Max Count */
 #define ABBR_FETCH			"A7"
-#define INI_SOCKET			"Socket"	/* Socket buffer size */
-#define ABBR_SOCKET			"A8"
+/*
+ * "Socket", abbreviated as "A8" was used for socket buffer. Now that we do
+ * everything through libpq, it's not used
+ */
 #define INI_READONLY			"ReadOnly"	/* Database is read only */
 #define ABBR_READONLY			"A0"
 #define INI_COMMLOG			"CommLog"	/* Communication to
 							 * backend logging */
 #define ABBR_COMMLOG			"B3"
-#define INI_PROTOCOL			"Protocol"	/* What protocol (6.2) */
+#define INI_PROTOCOL			"Protocol"	/* Controls rollback-on-error
+											 * behavior. Called "Protocol"
+											 * for historical reasons */
 #define ABBR_PROTOCOL			"A1"
-#define INI_OPTIMIZER			"Optimizer"	/* Use backend genetic
-							 * optimizer */
+/*	"Optimizer", abbreviated to B4 used to stand for "disable genetic query
+ * optimizer". No longer supported, you can use generic ConnSettings instead.
+#define INI_OPTIMIZER			"Optimizer"
 #define ABBR_OPTIMIZER			"B4"
-#define INI_KSQO			"Ksqo"		/* Keyset query
-							 * optimization */
-#define ABBR_KSQO			"B5"
+*/
+/* "Ksqo", abbreviated to B5 was used with pre-7.1 server versions for
+ * "keyset query optimization". No longer used.
+#define INI_KSQO                       "Ksqo"
+#define ABBR_KSQO                      "B5"
+*/
 #define INI_CONNSETTINGS		 "ConnSettings" /* Anything to send to
 							 * backend on successful
 							 * connection */
@@ -91,8 +95,12 @@ extern "C" {
 							 * result set sizes */
 #define ABBR_UNKNOWNSIZES		"A9"
 
+/* "CancelAsFreeStmt", abbreviated to "C1" was used with ODBC versions older
+ * than 3.51. It was a hack that made SQLCancel to imply
+ * SQLFreeStmt(SQL_CLOSE). It never had an effect in > 3.51 mode.
 #define INI_CANCELASFREESTMT		"CancelAsFreeStmt"
 #define ABBR_CANCELASFREESTMT	"C1"
+*/
 #define INI_USEDECLAREFETCH		"UseDeclareFetch"	/* Use Declare/Fetch
 								 * cursors */
 #define ABBR_USEDECLAREFETCH		"B6"
@@ -126,8 +134,14 @@ extern "C" {
 #define INI_TRANSLATIONNAME		"TranslationName"
 #define INI_TRANSLATIONDLL		"TranslationDLL"
 #define INI_TRANSLATIONOPTION		"TranslationOption"
-#define INI_DISALLOWPREMATURE		"DisallowPremature"
-#define ABBR_DISALLOWPREMATURE		"C3"
+/*
+ * "DisallowPremature", abbreviated "C3", used to mean that we should not
+ * execute a statement prematurely, before SQLExecute() when e.g.
+ * SQLPrepare+SQLDescribeCol is called. We never do that anymore.
+ *
+#define INI_DISALLOWPREMATURE          "DisallowPremature"
+#define ABBR_DISALLOWPREMATURE         "C3"
+*/
 #define INI_UPDATABLECURSORS		"UpdatableCursors"
 #define ABBR_UPDATABLECURSORS		"C4"
 #define INI_LFCONVERSION		"LFConversion"
@@ -152,8 +166,11 @@ extern "C" {
 #define INI_KEEPALIVEINTERVAL		"KeepaliveInterval"
 #define ABBR_KEEPALIVEINTERVAL		"D2"
 #define INI_DTCLOG			"Dtclog"
+/* "PreferLibpq", abbreviated "D4", used to mean whether to prefer libpq.
+ * libpq is now required
 #define INI_PREFERLIBPQ			"PreferLibpq"
 #define ABBR_PREFERLIBPQ		"D3"
+*/
 #define ABBR_XAOPT			"D4"
 
 #define	SSLMODE_DISABLE		"disable"
@@ -171,17 +188,13 @@ extern "C" {
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 #define INI_XAOPT			"XaOpt"
 #endif /* _HANDLE_ENLIST_IN_DTC_ */
-/* Bit representaion for abbreviated connection strings */
+/* Bit representation for abbreviated connection strings */
 #define BIT_LFCONVERSION			(1L)
 #define BIT_UPDATABLECURSORS			(1L<<1)
-#define BIT_DISALLOWPREMATURE			(1L<<2)
+/* #define BIT_DISALLOWPREMATURE                  (1L<<2) */
 #define BIT_UNIQUEINDEX				(1L<<3)
-#define BIT_PROTOCOL_63				(1L<<4)
-#define BIT_PROTOCOL_64				(1L<<5)
 #define BIT_UNKNOWN_DONTKNOW			(1L<<6)
 #define BIT_UNKNOWN_ASMAX			(1L<<7)
-#define BIT_OPTIMIZER				(1L<<8)
-#define BIT_KSQO				(1L<<9)
 #define BIT_COMMLOG				(1L<<10)
 #define BIT_DEBUG				(1L<<11)
 #define BIT_PARSE				(1L<<12)
@@ -213,7 +226,6 @@ extern "C" {
 #define	BIT_DISABLE_KEEPALIVE			(1L << 6)
 
 /*	Connection Defaults */
-#define DEFAULT_PORT				"5432"
 #define DEFAULT_READONLY			0
 #define DEFAULT_PROTOCOL			"7.4"	/* the latest protocol is
 												 * the default */
@@ -221,8 +233,6 @@ extern "C" {
 #define DEFAULT_TEXTASLONGVARCHAR		1
 #define DEFAULT_UNKNOWNSASLONGVARCHAR		0
 #define DEFAULT_BOOLSASCHAR			1
-#define DEFAULT_OPTIMIZER			0		/* enable */
-#define DEFAULT_KSQO				1		/* on */
 #define DEFAULT_UNIQUEINDEX			1		/* dont recognize */
 #define DEFAULT_COMMLOG				0		/* dont log */
 #define DEFAULT_DEBUG				0
@@ -238,9 +248,8 @@ extern "C" {
 
 #define DEFAULT_CANCELASFREESTMT		0
 
-#define DEFAULT_EXTRASYSTABLEPREFIXES	"dd_;"
+#define DEFAULT_EXTRASYSTABLEPREFIXES	"dd_"
 
-#define DEFAULT_DISALLOWPREMATURE	0
 #define DEFAULT_TRUEISMINUS1		0
 #define DEFAULT_UPDATABLECURSORS	1
 #ifdef	WIN32
@@ -292,7 +301,6 @@ LRESULT CALLBACK manage_dsnProc(HWND hdlg,
 			   LPARAM lParam);
 #endif   /* WIN32 */
 
-void		updateGlobals(void);
 int		writeDriverCommoninfo(const char *fileName, const char *sectionName,
 		const GLOBAL_VALUES *);
 void		writeDSNinfo(const ConnInfo *ci);
@@ -304,7 +312,6 @@ BOOL		copyCommonAttributes(ConnInfo *ci, const char *attribute, const char *valu
 int	getDriverNameFromDSN(const char *dsn, char *driver_name, int namelen);
 int	getLogDir(char *dir, int dirmax);
 int	setLogDir(const char *dir);
-int     changeDriverNameOfaDSN(const char *dsn, const char *driver_name, DWORD *errcode);
 UInt4	getExtraOptions(const ConnInfo *);
 BOOL	setExtraOptions(ConnInfo *, const char *str, const char *format);
 char	*extract_extra_attribute_setting(const pgNAME setting, const char *attr);
