@@ -193,7 +193,6 @@ inolog("a2\n");
 
 	mylog("%s: calling PGAPI_Execute...\n", func);
 
-	flag = SC_is_with_hold(stmt) ? PODBC_WITH_HOLD : 0;
 	result = PGAPI_Execute(hstmt, flag);
 
 	mylog("%s: returned %hd from PGAPI_Execute\n", func, result);
@@ -966,6 +965,11 @@ PGAPI_Execute(HSTMT hstmt, UWORD flag)
 		}
 mylog("prepareParameters was %s called, prepare state:%d\n", shouldParse == nCallParse ? "" : "not", stmt->prepare);
 
+		if (shouldParse == nCallParse &&
+		    PREPARE_BY_THE_DRIVER == stmt->prepare)
+		{
+			SC_set_Result(stmt, NULL);
+		}
 		if (ipdopts->param_processed_ptr)
 			*ipdopts->param_processed_ptr = 0;
 		/*
