@@ -38,48 +38,6 @@
 #include "qresult.h"
 #include "loadlib.h"
 
-#if (ODBCVER < 0x0300)
-RETCODE		SQL_API
-SQLAllocConnect(HENV EnvironmentHandle,
-				HDBC FAR * ConnectionHandle)
-{
-	RETCODE	ret;
-	EnvironmentClass *env = (EnvironmentClass *) EnvironmentHandle;
-
-	mylog("[SQLAllocConnect]");
-	ENTER_ENV_CS(env);
-	ret = PGAPI_AllocConnect(EnvironmentHandle, ConnectionHandle);
-	LEAVE_ENV_CS(env);
-	return ret;
-}
-
-RETCODE		SQL_API
-SQLAllocEnv(HENV FAR * EnvironmentHandle)
-{
-	RETCODE	ret;
-
-	mylog("[SQLAllocEnv]");
-	ret = PGAPI_AllocEnv(EnvironmentHandle);
-	return ret;
-}
-
-RETCODE		SQL_API
-SQLAllocStmt(HDBC ConnectionHandle,
-			 HSTMT *StatementHandle)
-{
-	RETCODE	ret;
-	ConnectionClass *conn = (ConnectionClass *) ConnectionHandle;
-
-	mylog("[SQLAllocStmt]");
-	CC_examine_global_transaction(conn);
-	ENTER_CONN_CS(conn);
-	CC_clear_error(conn);
-	ret = PGAPI_AllocStmt(ConnectionHandle, StatementHandle, PODBC_EXTERNAL_STATEMENT | PODBC_INHERIT_CONNECT_OPTIONS);
-	LEAVE_CONN_CS(conn);
-	return ret;
-}
-#endif /* ODBCVER */
-
 RETCODE		SQL_API
 SQLBindCol(HSTMT StatementHandle,
 		   SQLUSMALLINT ColumnNumber, SQLSMALLINT TargetType,
@@ -135,10 +93,8 @@ SQLColumns(HSTMT StatementHandle,
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
 	StartRollbackState(stmt);
-#if (ODBCVER >= 0x0300)
 	if (stmt->options.metadata_id)
 		flag |= PODBC_NOT_SEARCH_PATTERN;
-#endif
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
@@ -217,11 +173,11 @@ SQLConnect(HDBC ConnectionHandle,
 RETCODE		SQL_API
 SQLDriverConnect(HDBC hdbc,
 				 HWND hwnd,
-				 SQLCHAR FAR * szConnStrIn,
+				 SQLCHAR * szConnStrIn,
 				 SQLSMALLINT cbConnStrIn,
-				 SQLCHAR FAR * szConnStrOut,
+				 SQLCHAR * szConnStrOut,
 				 SQLSMALLINT cbConnStrOutMax,
-				 SQLSMALLINT FAR * pcbConnStrOut,
+				 SQLSMALLINT * pcbConnStrOut,
 				 SQLUSMALLINT fDriverCompletion)
 {
 	RETCODE	ret;
@@ -316,28 +272,6 @@ SQLDisconnect(HDBC ConnectionHandle)
 	return ret;
 }
 
-#if (ODBCVER < 0x0300)
-RETCODE		SQL_API
-SQLError(HENV EnvironmentHandle,
-		 HDBC ConnectionHandle, HSTMT StatementHandle,
-		 SQLCHAR *Sqlstate, SQLINTEGER *NativeError,
-		 SQLCHAR *MessageText, SQLSMALLINT BufferLength,
-		 SQLSMALLINT *TextLength)
-{
-	RETCODE	ret;
-
-	mylog("[SQLError]");
-	if (NULL != EnvironmentHandle)
-		ENTER_ENV_CS((EnvironmentClass *) EnvironmentHandle);
-	ret = PGAPI_Error(EnvironmentHandle, ConnectionHandle, StatementHandle,
-		   Sqlstate, NativeError, MessageText, BufferLength,
-		TextLength);
-	if (NULL != EnvironmentHandle)
-		LEAVE_ENV_CS((EnvironmentClass *) EnvironmentHandle);
-	return ret;
-}
-#endif /* ODBCVER */
-
 RETCODE		SQL_API
 SQLExecDirect(HSTMT StatementHandle,
 			  SQLCHAR *StatementText, SQLINTEGER TextLength)
@@ -350,8 +284,7 @@ SQLExecDirect(HSTMT StatementHandle,
 	mylog("[%s]", func);
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
-	if (PG_VERSION_GE(SC_get_conn(stmt), 7.4))
-		flag |= PODBC_WITH_HOLD;
+	flag |= PODBC_WITH_HOLD;
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
@@ -375,8 +308,7 @@ SQLExecute(HSTMT StatementHandle)
 	mylog("[%s]", func);
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
-	if (PG_VERSION_GE(SC_get_conn(stmt), 7.4))
-		flag |= PODBC_WITH_HOLD;
+	flag |= PODBC_WITH_HOLD;
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
@@ -396,55 +328,25 @@ SQLFetch(HSTMT StatementHandle)
 	CSTR func = "SQLFetch";
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
+	IRDFields	*irdopts = SC_get_IRDF(stmt);
+	ARDFields	*ardopts = SC_get_ARDF(stmt);
+	SQLUSMALLINT *rowStatusArray = irdopts->rowStatusArray;
+	SQLULEN *pcRow = irdopts->rowsFetched;
 
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
 	StartRollbackState(stmt);
-#if (ODBCVER >= 0x0300)
-	if (SC_get_conn(stmt)->driver_version >= 0x0300)
-	{
-		IRDFields	*irdopts = SC_get_IRDF(stmt);
-		ARDFields	*ardopts = SC_get_ARDF(stmt);
-		SQLUSMALLINT *rowStatusArray = irdopts->rowStatusArray;
-		SQLULEN *pcRow = irdopts->rowsFetched;
 
-		mylog("[[%s]]", func);
-		ret = PGAPI_ExtendedFetch(StatementHandle, SQL_FETCH_NEXT, 0,
-								   pcRow, rowStatusArray, 0, ardopts->size_of_rowset);
-		stmt->transition_status = STMT_TRANSITION_FETCH_SCROLL;
-	}
-	else
-#endif
-	{
-		mylog("[%s]", func);
-		ret = PGAPI_Fetch(StatementHandle);
-	}
+	mylog("[[%s]]", func);
+	ret = PGAPI_ExtendedFetch(StatementHandle, SQL_FETCH_NEXT, 0,
+							   pcRow, rowStatusArray, 0, ardopts->size_of_rowset);
+	stmt->transition_status = STMT_TRANSITION_FETCH_SCROLL;
+
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	return ret;
 }
 
-#if (ODBCVER < 0x0300)
-RETCODE		SQL_API
-SQLFreeConnect(HDBC ConnectionHandle)
-{
-	RETCODE	ret;
-
-	mylog("[SQLFreeConnect]");
-	ret = PGAPI_FreeConnect(ConnectionHandle);
-	return ret;
-}
-
-RETCODE		SQL_API
-SQLFreeEnv(HENV EnvironmentHandle)
-{
-	RETCODE	ret;
-
-	mylog("[SQLFreeEnv]");
-	ret = PGAPI_FreeEnv(EnvironmentHandle);
-	return ret;
-}
-#endif /* ODBCVER */
 
 RETCODE		SQL_API
 SQLFreeStmt(HSTMT StatementHandle,
@@ -484,23 +386,6 @@ SQLFreeStmt(HSTMT StatementHandle,
 	return ret;
 }
 
-#if (ODBCVER < 0x0300)
-RETCODE		SQL_API
-SQLGetConnectOption(HDBC ConnectionHandle,
-					SQLUSMALLINT Option, PTR Value)
-{
-	RETCODE	ret;
-	ConnectionClass *conn = (ConnectionClass *) ConnectionHandle;
-
-	mylog("[SQLGetConnectOption]");
-	CC_examine_global_transaction(conn);
-	ENTER_CONN_CS(conn);
-	CC_clear_error(conn);
-	ret = PGAPI_GetConnectOption(ConnectionHandle, Option, Value, NULL, 64);
-	LEAVE_CONN_CS(conn);
-	return ret;
-}
-#endif /* ODBCVER */
 
 RETCODE		SQL_API
 SQLGetCursorName(HSTMT StatementHandle,
@@ -552,14 +437,11 @@ SQLGetFunctions(HDBC ConnectionHandle,
 	CC_examine_global_transaction(conn);
 	ENTER_CONN_CS(conn);
 	CC_clear_error(conn);
-#if (ODBCVER >= 0x0300)
 	if (FunctionId == SQL_API_ODBC3_ALL_FUNCTIONS)
 		ret = PGAPI_GetFunctions30(ConnectionHandle, FunctionId, Supported);
 	else
-#endif
-	{
 		ret = PGAPI_GetFunctions(ConnectionHandle, FunctionId, Supported);
-	}
+
 	LEAVE_CONN_CS(conn);
 	return ret;
 }
@@ -575,51 +457,14 @@ SQLGetInfo(HDBC ConnectionHandle,
 	CC_examine_global_transaction(conn);
 	ENTER_CONN_CS(conn);
 	CC_clear_error(conn);
-#if (ODBCVER >= 0x0300)
 	mylog("[%s(30)]", func);
 	if ((ret = PGAPI_GetInfo(ConnectionHandle, InfoType, InfoValue,
 				BufferLength, StringLength)) == SQL_ERROR)
-	{
-		if (conn->driver_version >= 0x0300)
-		{
-			CC_clear_error(conn);
-			ret = PGAPI_GetInfo30(ConnectionHandle, InfoType, InfoValue,
-								   BufferLength, StringLength);
-			goto cleanup;
-		}
-	}
-	if (SQL_ERROR == ret)
 		CC_log_error("SQLGetInfo(30)", "", conn);
-#else
-	mylog("[%s]", func);
-	if (ret = PGAPI_GetInfo(ConnectionHandle, InfoType, InfoValue,
-			BufferLength, StringLength), SQL_ERROR == ret)
-		CC_log_error(func, "", conn);
-#endif
-cleanup:
 	LEAVE_CONN_CS(conn);
 	return ret;
 }
 
-#if (ODBCVER < 0x0300)
-RETCODE		SQL_API
-SQLGetStmtOption(HSTMT StatementHandle,
-				 SQLUSMALLINT Option, PTR Value)
-{
-	CSTR	func = "SQLGetStmtOption";
-	RETCODE	ret;
-	StatementClass *stmt = (StatementClass *) StatementHandle;
-
-	mylog("[%s]", func);
-	ENTER_STMT_CS(stmt);
-	SC_clear_error(stmt);
-	StartRollbackState(stmt);
-	ret = PGAPI_GetStmtOption(StatementHandle, Option, Value, NULL, 64);
-	ret = DiscardStatementSvp(stmt, ret, FALSE);
-	LEAVE_STMT_CS(stmt);
-	return ret;
-}
-#endif /* ODBCVER */
 
 RETCODE		SQL_API
 SQLGetTypeInfo(HSTMT StatementHandle,
@@ -733,23 +578,6 @@ SQLRowCount(HSTMT StatementHandle,
 	return ret;
 }
 
-#if (ODBCVER < 0x0300)
-RETCODE		SQL_API
-SQLSetConnectOption(HDBC ConnectionHandle,
-					SQLUSMALLINT Option, SQLULEN Value)
-{
-	RETCODE	ret;
-	ConnectionClass *conn = (ConnectionClass *) ConnectionHandle;
-
-	mylog("[SQLSetConnectionOption]");
-	CC_examine_global_transaction(conn);
-	ENTER_CONN_CS(conn);
-	CC_clear_error(conn);
-	ret = PGAPI_SetConnectOption(ConnectionHandle, Option, Value);
-	LEAVE_CONN_CS(conn);
-	return ret;
-}
-#endif /* ODBCVER */
 
 RETCODE		SQL_API
 SQLSetCursorName(HSTMT StatementHandle,
@@ -786,24 +614,6 @@ SQLSetParam(HSTMT StatementHandle,
 	return SQL_ERROR;
 }
 
-#if (ODBCVER < 0x0300)
-RETCODE		SQL_API
-SQLSetStmtOption(HSTMT StatementHandle,
-				 SQLUSMALLINT Option, SQLULEN Value)
-{
-	RETCODE	ret;
-	StatementClass *stmt = (StatementClass *) StatementHandle;
-
-	mylog("[SQLSetStmtOption]");
-	ENTER_STMT_CS(stmt);
-	SC_clear_error(stmt);
-	StartRollbackState(stmt);
-	ret = PGAPI_SetStmtOption(StatementHandle, Option, Value);
-	ret = DiscardStatementSvp(stmt, ret, FALSE);
-	LEAVE_STMT_CS(stmt);
-	return ret;
-}
-#endif /* ODBCVER */
 
 RETCODE		SQL_API
 SQLSpecialColumns(HSTMT StatementHandle,
@@ -949,10 +759,8 @@ SQLTables(HSTMT StatementHandle,
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
 	StartRollbackState(stmt);
-#if (ODBCVER >= 0x0300)
 	if (stmt->options.metadata_id)
 		flag |= PODBC_NOT_SEARCH_PATTERN;
-#endif
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
@@ -1000,49 +808,6 @@ SQLTables(HSTMT StatementHandle,
 	return ret;
 }
 
-#if (ODBCVER < 0x0300)
-RETCODE		SQL_API
-SQLTransact(HENV EnvironmentHandle,
-			HDBC ConnectionHandle, SQLUSMALLINT CompletionType)
-{
-	RETCODE	ret;
-
-	mylog("[SQLTransact]");
-	if (NULL != EnvironmentHandle)
-		ENTER_ENV_CS((EnvironmentClass *) EnvironmentHandle);
-	else
-		ENTER_CONN_CS((ConnectionClass *) ConnectionHandle);
-	ret = PGAPI_Transact(EnvironmentHandle, ConnectionHandle, CompletionType);
-	if (NULL != EnvironmentHandle)
-		LEAVE_ENV_CS((EnvironmentClass *) EnvironmentHandle);
-	else
-		LEAVE_CONN_CS((ConnectionClass *) ConnectionHandle);
-	return ret;
-}
-
-RETCODE		SQL_API
-SQLColAttributes(HSTMT hstmt,
-				 SQLUSMALLINT icol,
-				 SQLUSMALLINT fDescType,
-				 PTR rgbDesc,
-				 SQLSMALLINT cbDescMax,
-				 SQLSMALLINT *pcbDesc,
-				 SQLLEN *pfDesc)
-{
-	RETCODE	ret;
-	StatementClass *stmt = (StatementClass *) hstmt;
-
-	mylog("[SQLColAttributes]");
-	ENTER_STMT_CS(stmt);
-	SC_clear_error(stmt);
-	StartRollbackState(stmt);
-	ret = PGAPI_ColAttributes(hstmt, icol, fDescType, rgbDesc,
-							   cbDescMax, pcbDesc, pfDesc);
-	ret = DiscardStatementSvp(stmt, ret, FALSE);
-	LEAVE_STMT_CS(stmt);
-	return ret;
-}
-#endif /* ODBCVER */
 
 RETCODE		SQL_API
 SQLColumnPrivileges(HSTMT hstmt,
@@ -1066,10 +831,8 @@ SQLColumnPrivileges(HSTMT hstmt,
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
 	StartRollbackState(stmt);
-#if (ODBCVER >= 0x0300)
 	if (stmt->options.metadata_id)
 		flag |= PODBC_NOT_SEARCH_PATTERN;
-#endif
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
@@ -1332,26 +1095,6 @@ SQLNumParams(HSTMT hstmt,
 	return ret;
 }
 
-#if (ODBCVER < 0x0300)
-RETCODE		SQL_API
-SQLParamOptions(HSTMT hstmt,
-				SQLULEN crow,
-				SQLULEN *pirow)
-{
-	RETCODE	ret;
-	StatementClass *stmt = (StatementClass *) hstmt;
-
-	mylog("[SQLParamOptions]");
-	ENTER_STMT_CS(stmt);
-	SC_clear_error(stmt);
-	StartRollbackState(stmt);
-	ret = PGAPI_ParamOptions(hstmt, crow, pirow);
-	ret = DiscardStatementSvp(stmt, ret, FALSE);
-	LEAVE_STMT_CS(stmt);
-	return ret;
-}
-#endif /* ODBCVER */
-
 RETCODE		SQL_API
 SQLPrimaryKeys(HSTMT hstmt,
 			   SQLCHAR *szCatalogName,
@@ -1438,10 +1181,8 @@ SQLProcedureColumns(HSTMT hstmt,
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
 	StartRollbackState(stmt);
-#if (ODBCVER >= 0x0300)
 	if (stmt->options.metadata_id)
 		flag |= PODBC_NOT_SEARCH_PATTERN;
-#endif
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
@@ -1516,10 +1257,8 @@ SQLProcedures(HSTMT hstmt,
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
 	StartRollbackState(stmt);
-#if (ODBCVER >= 0x0300)
 	if (stmt->options.metadata_id)
 		flag |= PODBC_NOT_SEARCH_PATTERN;
-#endif
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
@@ -1605,10 +1344,8 @@ SQLTablePrivileges(HSTMT hstmt,
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
 	StartRollbackState(stmt);
-#if (ODBCVER >= 0x0300)
 	if (stmt->options.metadata_id)
 		flag |= PODBC_NOT_SEARCH_PATTERN;
-#endif
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
