@@ -21,7 +21,6 @@
 #include "psqlodbc.h"
 #include "misc.h"
 
-#if (ODBCVER >= 0x0300)
 #include <stdio.h>
 #include <string.h>
 
@@ -684,4 +683,3 @@ SQLBulkOperations(HSTMT hstmt, SQLSMALLINT operation)
 	LEAVE_STMT_CS(stmt);
 	return ret;
 }
-#endif /* ODBCVER >= 0x0300 */
