@@ -21,14 +21,10 @@
 #include "psqlodbc.h"
 #include "dlg_specific.h"
 #include "environ.h"
-#ifdef	USE_SSPI
-#include "sspisvcs.h"
-#endif /* USE_SSPI */
 #include "misc.h"
 
 #ifdef WIN32
 #include "loadlib.h"
-int	platformId = 0;
 #endif
 
 static int	exepgm = 0;
@@ -110,14 +106,11 @@ void	copy_globals(GLOBAL_VALUES *to, const GLOBAL_VALUES *from)
 	***/
 	NAME_TO_NAME(to->drivername, from->drivername);
 	CORR_VALCPY(fetch_max);
-	CORR_VALCPY(socket_buffersize);
 	CORR_VALCPY(unknown_sizes);
 	CORR_VALCPY(max_varchar_size);
 	CORR_VALCPY(max_longvarchar_size);
 	CORR_VALCPY(debug);
 	CORR_VALCPY(commlog);
-	CORR_VALCPY(disable_optimizer);
-	CORR_VALCPY(ksqo);
 	CORR_VALCPY(unique_index);
 	CORR_VALCPY(onlyread);		/* readonly is reserved on Digital C++
 								 * compiler */
@@ -127,12 +120,11 @@ void	copy_globals(GLOBAL_VALUES *to, const GLOBAL_VALUES *from)
 	CORR_VALCPY(bools_as_char);
 	CORR_VALCPY(lie);
 	CORR_VALCPY(parse);
-	CORR_VALCPY(cancel_as_freestmt);
 	CORR_STRCPY(extra_systable_prefixes);
 	CORR_STRCPY(protocol);
 	NAME_TO_NAME(to->conn_settings, from->conn_settings);
 
-	mylog("copy_globals driver=%s socket_buffersize=%d\n", SAFE_NAME(to->drivername), to->socket_buffersize);
+	mylog("copy_globals driver=%s\n", SAFE_NAME(to->drivername));
 }
 #undef	CORR_STRCPY
 #undef	CORR_VALCPY
@@ -157,7 +149,7 @@ static void finalize_global_cs(void)
 }
 
 #ifdef WIN32
-HINSTANCE NEAR s_hModule;		/* Saved module handle. */
+HINSTANCE s_hModule;		/* Saved module handle. */
 /*	This is where the Driver Manager attaches to this Driver */
 BOOL		WINAPI
 DllMain(HANDLE hInst, ULONG ul_reason_for_call, LPVOID lpReserved)
@@ -171,6 +163,7 @@ DllMain(HANDLE hInst, ULONG ul_reason_for_call, LPVOID lpReserved)
 			{
 				char	pathname[_MAX_PATH], fname[_MAX_FNAME];
 				OSVERSIONINFO	osversion;
+				int platformId = 0;
 
 				getCommonDefaults(DBMS_NAME, ODBCINST_INI, NULL);
 				if (GetModuleFileName(NULL, pathname, sizeof(pathname)) > 0)
@@ -197,9 +190,6 @@ DllMain(HANDLE hInst, ULONG ul_reason_for_call, LPVOID lpReserved)
 
 		case DLL_PROCESS_DETACH:
 			mylog("DETACHING PROCESS\n");
-#ifdef	USE_SSPI
-			LeaveSSPIService();
-#endif /* USE_SSPI */
 			CleanupDelayLoadedDLLs();
 			/* my(q)log is unavailable from here */
 			finalize_global_cs();
