@@ -468,6 +468,7 @@ typedef struct StatementOptions_
 	SQLUINTEGER		use_bookmarks;
 	void			*bookmark_ptr;
 	SQLUINTEGER		metadata_id;
+	SQLULEN			stmt_timeout;
 } StatementOptions;
 
 /*	Used to pass extra query info to send_query */
@@ -554,6 +555,7 @@ int	wstrtomsg(const LPWSTR, int, char *, int);
 CSTR	NULL_STRING = "";
 CSTR	PRINT_NULL = "(null)";
 #define OID_NAME "oid"
+#define TABLEOID_NAME "tableoid"
 
 #ifdef	__cplusplus
 }
