@@ -388,7 +388,7 @@ ConfigDlgProc(HWND hdlg,
 			{
 				HBRUSH hBrush = (HBRUSH)GetStockObject(LTGRAY_BRUSH);
 				SetTextColor((HDC)wParam, RGB(255, 0, 0));
-				return (long)hBrush;
+				return (LRESULT)hBrush;
 			}
 			break;
 	}
@@ -400,7 +400,7 @@ ConfigDlgProc(HWND hdlg,
 void
 test_connection(HANDLE hwnd, ConnInfo *ci, BOOL withDTC)
 {
-	EnvironmentClass *env = EN_Constructor();
+	EnvironmentClass *env;
 	ConnectionClass *conn = NULL;
 	char    szMsg[SQL_MAX_MESSAGE_LENGTH];
 	char *emsg = NULL;
@@ -486,12 +486,18 @@ cleanup:
 
 		tlen = strlen(emsg);
 		wermsg = (SQLWCHAR *) malloc(sizeof(SQLWCHAR) * (tlen + 1));
-		ulen = utf8_to_ucs2_lf(emsg, SQL_NTS, FALSE, wermsg, tlen + 1, TRUE);
+		if (wermsg)
+			ulen = utf8_to_ucs2_lf(emsg, SQL_NTS, FALSE, wermsg, tlen + 1, TRUE);
+		else
+			ulen = (SQLULEN) -1;
 		if (ulen != (SQLULEN) -1)
 		{
 			allocstr = malloc(4 * tlen + 1);
-			(void) wstrtomsg(wermsg, (int) tlen, allocstr, (int) (4 * tlen + 1));
-			emsg = allocstr;
+			if (allocstr)
+			{
+				(void) wstrtomsg(wermsg, (int) tlen, allocstr, (int) (4 * tlen + 1));
+				emsg = allocstr;
+			}
 		}
 #endif /* UNICODE_SUPPORT */
 
