@@ -52,9 +52,8 @@ runTest(HSTMT hstmt)
 
 int main(int argc, char **argv)
 {
-	int rc;
-	HSTMT hstmt = SQL_NULL_HSTMT;
-	int i;
+	int			rc;
+	HSTMT		hstmt = SQL_NULL_HSTMT;
 
 	/**** Test WITH-queries in with and without  UseDeclareFetch. ****/
 	/*
@@ -87,4 +86,6 @@ int main(int argc, char **argv)
 
 	/* Clean up */
 	test_disconnect();
+
+	return 0;
 }
